==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/ApiPortalCustomDomain.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin

import com.pulumi.azurenative.appplatform.kotlin.outputs.ApiPortalCustomDomainPropertiesResponse
import com.pulumi.azurenative.appplatform.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.appplatform.kotlin.outputs.ApiPortalCustomDomainPropertiesResponse.Companion.toKotlin as apiPortalCustomDomainPropertiesResponseToKotlin
import com.pulumi.azurenative.appplatform.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [ApiPortalCustomDomain].
 */
@PulumiTagMarker
public class ApiPortalCustomDomainResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ApiPortalCustomDomainArgs = ApiPortalCustomDomainArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ApiPortalCustomDomainArgsBuilder.() -> Unit) {
        val builder = ApiPortalCustomDomainArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ApiPortalCustomDomain {
        val builtJavaResource =
            com.pulumi.azurenative.appplatform.ApiPortalCustomDomain(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ApiPortalCustomDomain(builtJavaResource)
    }
}

/**
 * Custom domain of the API portal
 * Azure REST API version: 2023-05-01-preview. Prior API version in Azure Native 1.x: 2022-01-01-preview.
 * Other available API versions: 2023-07-01-preview, 2023-09-01-preview, 2023-11-01-preview, 2023-12-01, 2024-01-01-preview.
 * ## Example Usage
 * ### ApiPortalCustomDomains_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var apiPortalCustomDomain = new AzureNative.AppPlatform.ApiPortalCustomDomain("apiPortalCustomDomain", new()
 *     {
 *         ApiPortalName = "default",
 *         DomainName = "myDomainName",
 *         Properties = new AzureNative.AppPlatform.Inputs.ApiPortalCustomDomainPropertiesArgs
 *         {
 *             Thumbprint = "*",
 *         },
 *         ResourceGroupName = "myResourceGroup",
 *         ServiceName = "myservice",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/appplatform/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := appplatform.NewApiPortalCustomDomain(ctx, "apiPortalCustomDomain", &appplatform.ApiPortalCustomDomainArgs{
 * 			ApiPortalName: pulumi.String("default"),
 * 			DomainName:    pulumi.String("myDomainName"),
 * 			Properties: &appplatform.ApiPortalCustomDomainPropertiesArgs{
 * 				Thumbprint: pulumi.String("*"),
 * 			},
 * 			ResourceGroupName: pulumi.String("myResourceGroup"),
 * 			ServiceName:       pulumi.String("myservice"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.appplatform.ApiPortalCustomDomain;
 * import com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs;
 * import com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var apiPortalCustomDomain = new ApiPortalCustomDomain("apiPortalCustomDomain", ApiPortalCustomDomainArgs.builder()
 *             .apiPortalName("default")
 *             .domainName("myDomainName")
 *             .properties(ApiPortalCustomDomainPropertiesArgs.builder()
 *                 .thumbprint("*")
 *                 .build())
 *             .resourceGroupName("myResourceGroup")
 *             .serviceName("myservice")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:appplatform:ApiPortalCustomDomain myDomainName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppPlatform/Spring/{serviceName}/apiPortals/{apiPortalName}/domains/{domainName}
 * ```
 */
public class ApiPortalCustomDomain internal constructor(
    override val javaResource: com.pulumi.azurenative.appplatform.ApiPortalCustomDomain,
) : KotlinCustomResource(javaResource, ApiPortalCustomDomainMapper) {
    /**
     * The name of the resource.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The properties of custom domain for API portal
     */
    public val properties: Output<ApiPortalCustomDomainPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                apiPortalCustomDomainPropertiesResponseToKotlin(args0)
            })
        })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The type of the resource.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ApiPortalCustomDomainMapper : ResourceMapper<ApiPortalCustomDomain> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.appplatform.ApiPortalCustomDomain::class == javaResource::class

    override fun map(javaResource: Resource): ApiPortalCustomDomain =
        ApiPortalCustomDomain(
            javaResource as
                com.pulumi.azurenative.appplatform.ApiPortalCustomDomain,
        )
}

/**
 * @see [ApiPortalCustomDomain].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ApiPortalCustomDomain].
 */
public suspend fun apiPortalCustomDomain(
    name: String,
    block: suspend ApiPortalCustomDomainResourceBuilder.() -> Unit,
): ApiPortalCustomDomain {
    val builder = ApiPortalCustomDomainResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ApiPortalCustomDomain].
 * @param name The _unique_ name of the resulting resource.
 */
public fun apiPortalCustomDomain(name: String): ApiPortalCustomDomain {
    val builder = ApiPortalCustomDomainResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/ApiPortalCustomDomain.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin

import com.pulumi.azurenative.appplatform.kotlin.outputs.ApiPortalCustomDomainPropertiesResponse
import com.pulumi.azurenative.appplatform.kotlin.outputs.SystemDataResponse
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import com.pulumi.azurenative.appplatform.kotlin.outputs.ApiPortalCustomDomainPropertiesResponse.Companion.toKotlin as apiPortalCustomDomainPropertiesResponseToKotlin
import com.pulumi.azurenative.appplatform.kotlin.outputs.SystemDataResponse.Companion.toKotlin as systemDataResponseToKotlin

/**
 * Builder for [ApiPortalCustomDomain].
 */
@PulumiTagMarker
public class ApiPortalCustomDomainResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: ApiPortalCustomDomainArgs = ApiPortalCustomDomainArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend ApiPortalCustomDomainArgsBuilder.() -> Unit) {
        val builder = ApiPortalCustomDomainArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): ApiPortalCustomDomain {
        val builtJavaResource =
            com.pulumi.azurenative.appplatform.ApiPortalCustomDomain(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return ApiPortalCustomDomain(builtJavaResource)
    }
}

/**
 * Custom domain of the API portal
 * Azure REST API version: 2023-05-01-preview. Prior API version in Azure Native 1.x: 2022-01-01-preview.
 * Other available API versions: 2023-07-01-preview, 2023-09-01-preview, 2023-11-01-preview, 2023-12-01, 2024-01-01-preview, 2024-05-01-preview.
 * ## Example Usage
 * ### ApiPortalCustomDomains_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var apiPortalCustomDomain = new AzureNative.AppPlatform.ApiPortalCustomDomain("apiPortalCustomDomain", new()
 *     {
 *         ApiPortalName = "default",
 *         DomainName = "myDomainName",
 *         Properties = new AzureNative.AppPlatform.Inputs.ApiPortalCustomDomainPropertiesArgs
 *         {
 *             Thumbprint = "*",
 *         },
 *         ResourceGroupName = "myResourceGroup",
 *         ServiceName = "myservice",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/appplatform/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := appplatform.NewApiPortalCustomDomain(ctx, "apiPortalCustomDomain", &appplatform.ApiPortalCustomDomainArgs{
 * 			ApiPortalName: pulumi.String("default"),
 * 			DomainName:    pulumi.String("myDomainName"),
 * 			Properties: &appplatform.ApiPortalCustomDomainPropertiesArgs{
 * 				Thumbprint: pulumi.String("*"),
 * 			},
 * 			ResourceGroupName: pulumi.String("myResourceGroup"),
 * 			ServiceName:       pulumi.String("myservice"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.appplatform.ApiPortalCustomDomain;
 * import com.pulumi.azurenative.appplatform.ApiPortalCustomDomainArgs;
 * import com.pulumi.azurenative.appplatform.inputs.ApiPortalCustomDomainPropertiesArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var apiPortalCustomDomain = new ApiPortalCustomDomain("apiPortalCustomDomain", ApiPortalCustomDomainArgs.builder()
 *             .apiPortalName("default")
 *             .domainName("myDomainName")
 *             .properties(ApiPortalCustomDomainPropertiesArgs.builder()
 *                 .thumbprint("*")
 *                 .build())
 *             .resourceGroupName("myResourceGroup")
 *             .serviceName("myservice")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:appplatform:ApiPortalCustomDomain myDomainName /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.AppPlatform/Spring/{serviceName}/apiPortals/{apiPortalName}/domains/{domainName}
 * ```
 */
public class ApiPortalCustomDomain internal constructor(
    override val javaResource: com.pulumi.azurenative.appplatform.ApiPortalCustomDomain,
) : KotlinCustomResource(javaResource, ApiPortalCustomDomainMapper) {
    /**
     * The name of the resource.
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The properties of custom domain for API portal
     */
    public val properties: Output<ApiPortalCustomDomainPropertiesResponse>
        get() = javaResource.properties().applyValue({ args0 ->
            args0.let({ args0 ->
                apiPortalCustomDomainPropertiesResponseToKotlin(args0)
            })
        })

    /**
     * Metadata pertaining to creation and last modification of the resource.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 ->
            args0.let({ args0 ->
                systemDataResponseToKotlin(args0)
            })
        })

    /**
     * The type of the resource.
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object ApiPortalCustomDomainMapper : ResourceMapper<ApiPortalCustomDomain> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.appplatform.ApiPortalCustomDomain::class == javaResource::class

    override fun map(javaResource: Resource): ApiPortalCustomDomain =
        ApiPortalCustomDomain(
            javaResource as
                com.pulumi.azurenative.appplatform.ApiPortalCustomDomain,
        )
}

/**
 * @see [ApiPortalCustomDomain].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [ApiPortalCustomDomain].
 */
public suspend fun apiPortalCustomDomain(
    name: String,
    block: suspend ApiPortalCustomDomainResourceBuilder.() -> Unit,
): ApiPortalCustomDomain {
    val builder = ApiPortalCustomDomainResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [ApiPortalCustomDomain].
 * @param name The _unique_ name of the resulting resource.
 */
public fun apiPortalCustomDomain(name: String): ApiPortalCustomDomain {
    val builder = ApiPortalCustomDomainResourceBuilder()
    builder.name(name)
    return builder.build()
}
